package de.timpt.x2h;

/*
This file is part of PJava.

PJava is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PJava is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
*/

import java.util.StringTokenizer;

import javax.swing.*;
import javax.swing.text.*;


/**
 * converts the XML/HTML to HTML
 */

public class X2HConverter {
  private X2HMainView     view;      // the view object
  
  /**
   * Constructor
   * @param view the X2H main view
   */
  protected X2HConverter(X2HMainView view){
    this.view = view;
  }
  
  /**
   * do the conversion
   */
  protected void doConversion(){
    String lineSeparator = System.getProperty("line.separator");
    view.resultTextArea.setText("");
    String bgColor = view.backgroundColor.getText();

    if (!bgColor.equals("")) {
      view.resultTextArea.append("<div style=\"background-color:#"+view.backgroundColor.getText()+";\">"+lineSeparator);
    }    
    else {
      view.resultTextArea.append("<div>"+lineSeparator);
    }    
    view.resultTextArea.append("<pre>"+lineSeparator);

    if (view.progLanguage.getSelectedIndex() == 0){
      doXMLStyleConversion();
    }
    else if (view.progLanguage.getSelectedIndex() == 1){
      doScalaConversion();
    }
    else{
      JOptionPane.showMessageDialog(view,"IllegalStateException");
      throw new IllegalStateException();
    }
    view.resultTextArea.append("<div align=\"right\">");
    view.resultTextArea.append("<small>");
    view.resultTextArea.append(X2HGlobal.getVersionString());
    view.resultTextArea.append("</small>");
    view.resultTextArea.append("</div>"+lineSeparator);
    view.resultTextArea.append("</pre>"+lineSeparator);
    view.resultTextArea.append("</div>"+lineSeparator);
  }
  
  /**
   * do the XML conversion
   */
  private void doXMLStyleConversion(){
    try {
      for (int i = 0; i < view.sourceTextArea.getLineCount(); ++i){
        String content = view.sourceTextArea.getLineString(i);
        content = convertHTMLEntities(content);
        view.resultTextArea.append(content);
      }
    }
    catch(BadLocationException ble){
      ble.printStackTrace();
      JOptionPane.showMessageDialog(view,"BadLocationException");
      System.exit(1);
    }    
  }
  
  /**
   * do the Scala conversion
   */
  private void doScalaConversion(){    
    try {
      for (int i = 0; i < view.sourceTextArea.getLineCount(); ++i){
        String content = view.sourceTextArea.getLineString(i);              
        // TODO include Link to X2H
        
        content = convertHTMLEntities(content);
        content = highlightScalaKeywords(content);
        
        view.resultTextArea.append(content);       
      }
    }
    catch(BadLocationException ble){
      ble.printStackTrace();
      JOptionPane.showMessageDialog(view,"BadLocationException");
      System.exit(1);
    } 
  }
  
  /**
   * highlights Scala keywords
   * @param s String asked for hilighting
   * @return String with hughlihtes Keywords
   */
  private String highlightScalaKeywords(String s){
    ScalaKeywords keywords = new ScalaKeywords();
    String result = "";
    StringTokenizer tokenizer = new StringTokenizer(s," ",true);
    while (tokenizer.hasMoreTokens()){
      String token = tokenizer.nextToken();
      if (keywords.isKeyword(token)) {
        result += "<b>"+token+"</b>";
      }
      else if (token.indexOf("(new") >= 0) {
        int index = token.indexOf("(new");
        result += token.substring(0,index+1);
        result += "<b>"+token.substring(index+1)+"</b>";
      }
      else result += token;
    }
    return result;
  }
  
  /**
   * converts HTML entitys
   * @param s String where HTML entities should be converted
   * @return converted String
   */
  private String convertHTMLEntities(String s){
    s = s.replaceAll("&","&amp;");
    s = s.replaceAll("<","&lt;");
    s = s.replaceAll(">","&gt;");        
    s = s.replaceAll("\"","&quot;");
    return s;
  }
}