package de.timpt.x2h;

/*
This file is part of X2H.

PJava is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

PJava is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with X2H.  If not, see <http://www.gnu.org/licenses/>.
*/

import java.awt.*;

import javax.swing.*;


/**
 * Main view class of X2H
 */
public class X2HMainView extends JFrame{
  private static final long serialVersionUID = 1551726334557373830L;
  protected PJTextArea    sourceTextArea,       // source code to convert
                          resultTextArea;       // result of the conversion
  protected JTextField    backgroundColor;      // background color of the result 
  protected JComboBox     progLanguage;         // programming language to convert
  
  
  /**
   * Constructor
   */
  protected X2HMainView(){
    super(X2HGlobal.getVersionString());
    createView();
  }
 
  /**
   * Creates the view
   */
  private void createView(){    
    add(createDataComponent());
    pack();
    setVisible(true);
  }
  
  /**
   * Creates the data panel
   */
  private JComponent createDataComponent(){
    JPanel panel = new JPanel(new GridBagLayout());
    GridBagConstraints gbc = new GridBagConstraints();
    gbc.anchor = GridBagConstraints.WEST;
    
    gbc.gridx = 0;
    gbc.gridy = 0;
    panel.add(new JLabel("Source code to convert"),gbc);
    gbc.gridy++;
    panel.add(new JScrollPane(sourceTextArea = new PJTextArea(10,72)),gbc);
    sourceTextArea.setFont(new Font("Monospaced",Font.PLAIN,12));

    gbc.gridy++;
    panel.add(new JLabel("Result of source code conversion"),gbc);
    gbc.gridy++;
    panel.add(new JScrollPane(resultTextArea = new PJTextArea(10,72)),gbc);
    resultTextArea.setFont(new Font("Monospaced",Font.PLAIN,12));
    
    gbc.gridy++;
    panel.add(createBackgroundColorComponent(),gbc);
    
    return panel;
  }
  
  /**
   * Creates the component to specify the background color
   */
  private JComponent createBackgroundColorComponent() {
    JPanel panel = new JPanel();
    panel.add(new JLabel("Background color"));
    panel.add(backgroundColor = new JTextField(10));
    backgroundColor.setText("ecf3f9");
    panel.add(new JLabel("Programming language"));
    panel.add(progLanguage = new JComboBox());
    
    progLanguage.addItem("XML-Style");
    progLanguage.addItem("Scala");
    
    return panel;
  }
}
